JiTCxDE Common is a collection common code for
`JiTCODE <http://github.com/neurophysik/jitcode>`_,
`JiTCDDE <http://github.com/neurophysik/jitcdde>`_, and
`JiTCSDE <http://github.com/neurophysik/jitcsde>`_.
You’ll need it if you install any of them manually.
Otherwise it should be automatically installed as a dependency.
